@@ -19,18 +19,14 @@ package org.apache.maven.plugin.surefire.booterclient;
  * under the License.
  */
 
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.PrintStream;
-import java.nio.charset.Charset;
-import java.util.List;
-import java.util.Properties;
-import java.util.StringTokenizer;
-
+import junit.framework.Assert;
+import junit.framework.TestCase;
+import org.apache.maven.plugin.surefire.booterclient.lazytestprovider.NotifiableTestStream;
 import org.apache.maven.plugin.surefire.booterclient.output.ForkClient;
+import org.apache.maven.plugin.surefire.log.api.ConsoleLogger;
+import org.apache.maven.plugin.surefire.log.api.NullConsoleLogger;
 import org.apache.maven.surefire.booter.ForkingRunListener;
 import org.apache.maven.surefire.report.CategorizedReportEntry;
-import org.apache.maven.surefire.report.ConsoleLogger;
 import org.apache.maven.surefire.report.ConsoleOutputReceiver;
 import org.apache.maven.surefire.report.LegacyPojoStackTraceWriter;
 import org.apache.maven.surefire.report.ReportEntry;
@@ -39,12 +35,17 @@ import org.apache.maven.surefire.report.RunListener;
 import org.apache.maven.surefire.report.SimpleReportEntry;
 import org.apache.maven.surefire.report.StackTraceWriter;
 
-import junit.framework.Assert;
-import junit.framework.TestCase;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.PrintStream;
+import java.nio.charset.Charset;
+import java.util.List;
+import java.util.Properties;
+import java.util.StringTokenizer;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
 
 /**
  * @author Kristian Rosenvold
@@ -52,10 +53,9 @@ import static org.hamcrest.MatcherAssert.assertThat;
 public class ForkingRunListenerTest
     extends TestCase
 {
+    private final ByteArrayOutputStream content, anotherContent;
 
-    private final ByteArrayOutputStream content;
-
-    private final PrintStream printStream;
+    private final PrintStream printStream, anotherPrintStream;
 
     final int defaultChannel = 17;
 
@@ -63,8 +63,11 @@ public class ForkingRunListenerTest
 
     public ForkingRunListenerTest()
     {
-        this.content = new ByteArrayOutputStream();
+        content = new ByteArrayOutputStream();
         printStream = new PrintStream( content );
+
+        anotherContent = new ByteArrayOutputStream();
+        anotherPrintStream = new PrintStream( anotherContent );
     }
 
     private void reset()
@@ -73,7 +76,6 @@ public class ForkingRunListenerTest
         content.reset();
     }
 
-
     public void testHeaderCreation()
     {
         final byte[] header = ForkingRunListener.createHeader( (byte) 'F', 0xCAFE );
@@ -220,8 +222,9 @@ public class ForkingRunListenerTest
 
         TestSetMockReporterFactory providerReporterFactory = new TestSetMockReporterFactory();
         final Properties testVmSystemProperties = new Properties();
+        NullConsoleLogger log = new NullConsoleLogger();
         ForkClient forkStreamClient = new ForkClient( providerReporterFactory, testVmSystemProperties,
-                                                      new MockNotifiableTestStream() );
+                                                      new MockNotifiableTestStream(), log );
 
         forkStreamClient.consumeMultiLineContent( content.toString( "utf-8" ) );
 
@@ -245,12 +248,13 @@ public class ForkingRunListenerTest
         forkingReporter.testSetCompleted( reportEntry );
 
         TestSetMockReporterFactory providerReporterFactory = new TestSetMockReporterFactory();
+        NullConsoleLogger log = new NullConsoleLogger();
         ForkClient forkStreamClient = new ForkClient( providerReporterFactory, new Properties(),
-                                                      new MockNotifiableTestStream() );
+                                                      new MockNotifiableTestStream(), log );
 
         forkStreamClient.consumeMultiLineContent( content.toString( "utf-8" ) );
 
-        final MockReporter reporter = (MockReporter) forkStreamClient.getReporter( defaultChannel );
+        final MockReporter reporter = (MockReporter) forkStreamClient.getReporter();
         final List<String> events = reporter.getEvents();
         assertEquals( MockReporter.SET_STARTING, events.get( 0 ) );
         assertEquals( MockReporter.TEST_STARTING, events.get( 1 ) );
@@ -265,20 +269,28 @@ public class ForkingRunListenerTest
         ReportEntry expected = createDefaultReportEntry();
         final SimpleReportEntry secondExpected = createAnotherDefaultReportEntry();
 
-        new ForkingRunListener( printStream, defaultChannel, false ).testStarting( expected );
-        new ForkingRunListener( printStream, anotherChannel, false ).testSkipped( secondExpected );
+        new ForkingRunListener( printStream, defaultChannel, false )
+                .testStarting( expected );
+
+        new ForkingRunListener( anotherPrintStream, anotherChannel, false )
+                .testSkipped( secondExpected );
 
         TestSetMockReporterFactory providerReporterFactory = new TestSetMockReporterFactory();
-        final ForkClient forkStreamClient = new ForkClient( providerReporterFactory, new Properties(),
-                                                            new MockNotifiableTestStream() );
+        Properties vmProps = new Properties();
+        NotifiableTestStream notifiableTestStream = new MockNotifiableTestStream();
+        NullConsoleLogger log = new NullConsoleLogger();
+
+        ForkClient forkStreamClient = new ForkClient( providerReporterFactory, vmProps, notifiableTestStream, log );
         forkStreamClient.consumeMultiLineContent( content.toString( "utf-8" ) );
 
-        MockReporter reporter = (MockReporter) forkStreamClient.getReporter( defaultChannel );
+        MockReporter reporter = (MockReporter) forkStreamClient.getReporter();
         Assert.assertEquals( MockReporter.TEST_STARTING, reporter.getFirstEvent() );
         Assert.assertEquals( expected, reporter.getFirstData() );
         Assert.assertEquals( 1, reporter.getEvents().size() );
 
-        MockReporter reporter2 = (MockReporter) forkStreamClient.getReporter( anotherChannel );
+        forkStreamClient = new ForkClient( providerReporterFactory, vmProps, notifiableTestStream, log );
+        forkStreamClient.consumeMultiLineContent( anotherContent.toString( "utf-8" ) );
+        MockReporter reporter2 = (MockReporter) forkStreamClient.getReporter();
         Assert.assertEquals( MockReporter.TEST_SKIPPED, reporter2.getFirstEvent() );
         Assert.assertEquals( secondExpected, reporter2.getFirstData() );
         Assert.assertEquals( 1, reporter2.getEvents().size() );
@@ -324,9 +336,9 @@ public class ForkingRunListenerTest
         }
     }
 
-    private RunListener createForkingRunListener( Integer testSetCHannel )
+    private RunListener createForkingRunListener( Integer testSetChannel )
     {
-        return new ForkingRunListener( printStream, testSetCHannel, false );
+        return new ForkingRunListener( printStream, testSetChannel, false );
     }
 
     private class StandardTestRun
@@ -344,10 +356,11 @@ public class ForkingRunListenerTest
             throws ReporterException, IOException
         {
             TestSetMockReporterFactory providerReporterFactory = new TestSetMockReporterFactory();
+            NullConsoleLogger log = new NullConsoleLogger();
             final ForkClient forkStreamClient = new ForkClient( providerReporterFactory, new Properties(),
-                                                                new MockNotifiableTestStream() );
+                                                                new MockNotifiableTestStream(), log );
             forkStreamClient.consumeMultiLineContent( content.toString( ) );
-            reporter = (MockReporter) forkStreamClient.getReporter( defaultChannel );
+            reporter = (MockReporter) forkStreamClient.getReporter();
         }
 
         public String getFirstEvent()
