@@ -19,10 +19,12 @@ package org.apache.maven.plugin.surefire.booterclient;
  * under the License.
  */
 
-import org.apache.maven.plugin.surefire.StartupReportConfiguration;
 import org.apache.maven.plugin.surefire.report.DefaultReporterFactory;
+import org.apache.maven.plugin.surefire.log.api.NullConsoleLogger;
 import org.apache.maven.surefire.report.RunListener;
 
+import static org.apache.maven.plugin.surefire.StartupReportConfiguration.defaultValue;
+
 /**
  * Internal tests use only.
  *
@@ -33,7 +35,7 @@ public class TestSetMockReporterFactory
 {
     public TestSetMockReporterFactory()
     {
-        super( StartupReportConfiguration.defaultValue() );
+        super( defaultValue(), new NullConsoleLogger() );
     }
 
     public RunListener createReporter()
