@@ -23,11 +23,20 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Locale;
 
+import org.apache.commons.lang3.JavaVersion;
+import org.apache.commons.lang3.SystemUtils;
+import org.apache.maven.plugin.surefire.log.api.ConsoleLogger;
+import org.apache.maven.plugin.surefire.log.api.PrintStreamLogger;
 import org.apache.maven.plugins.surefire.report.ReportTestSuite;
 import org.apache.maven.plugins.surefire.report.SurefireReportParser;
 
-import static junit.framework.Assert.assertTrue;
 import static junit.framework.Assert.assertEquals;
+import static junit.framework.Assert.assertTrue;
+import static org.apache.commons.lang3.SystemUtils.JAVA_SPECIFICATION_VERSION;
+import static org.hamcrest.Matchers.greaterThanOrEqualTo;
+import static org.hamcrest.Matchers.is;
+import static org.junit.Assume.assumeThat;
+import static org.junit.Assume.assumeTrue;
 
 @SuppressWarnings( { "JavaDoc" } )
 public class HelperAssertions
@@ -129,7 +138,8 @@ public class HelperAssertions
             assertTrue( "Reports directory is missing: " + reportsDir.getAbsolutePath(), reportsDir.exists() );
             reportsDirs.add( reportsDir );
         }
-        SurefireReportParser parser = new SurefireReportParser( reportsDirs, Locale.getDefault() );
+        ConsoleLogger logger = new PrintStreamLogger( System.out );
+        SurefireReportParser parser = new SurefireReportParser( reportsDirs, Locale.getDefault(), logger );
         try
         {
             return parser.parseXMLReportFiles();
@@ -149,7 +159,8 @@ public class HelperAssertions
             assertTrue( "Reports directory is missing: " + reportsDir.getAbsolutePath(), reportsDir.exists() );
             reportsDirs.add( reportsDir );
         }
-        SurefireReportParser parser = new SurefireReportParser( reportsDirs, Locale.getDefault() );
+        ConsoleLogger logger = new PrintStreamLogger( System.out );
+        SurefireReportParser parser = new SurefireReportParser( reportsDirs, Locale.getDefault(), logger );
         try
         {
             return parser.parseXMLReportFiles();
@@ -159,4 +170,10 @@ public class HelperAssertions
             throw new RuntimeException( "Couldn't parse XML reports", e );
         }
     }
+
+    public static void assumeJavaVersion( JavaVersion version )
+    {
+        assumeTrue( "java.specification.version: " + JAVA_SPECIFICATION_VERSION,
+                SystemUtils.isJavaVersionAtLeast( version ) );
+    }
 }
