@@ -22,9 +22,12 @@ package org.apache.maven.surefire.common.junit4;
 import org.apache.maven.surefire.report.SafeThrowable;
 import org.apache.maven.surefire.report.SmartStackTraceParser;
 import org.apache.maven.surefire.report.StackTraceWriter;
-
 import org.junit.runner.notification.Failure;
 
+import static org.apache.maven.surefire.util.internal.TestClassMethodNameUtils.extractClassName;
+import static org.apache.maven.surefire.util.internal.TestClassMethodNameUtils.extractMethodName;
+import static org.apache.maven.surefire.report.SmartStackTraceParser.stackTraceWithFocusOnClassAsString;
+
 /**
  * Writes out a specific {@link org.junit.runner.notification.Failure} for
  * surefire as a stacktrace.
@@ -74,15 +77,14 @@ public class JUnit4StackTraceWriter
         return "";
     }
 
-
     protected String getTestClassName()
     {
-        return JUnit4RunListener.extractClassName( junitFailure.getDescription() );
+        return extractClassName( junitFailure.getDescription().getDisplayName() );
     }
 
     protected String getTestMethodName()
     {
-        return JUnit4RunListener.extractMethodName( junitFailure.getDescription() );
+        return extractMethodName( junitFailure.getDescription().getDisplayName() );
     }
 
     @SuppressWarnings( "ThrowableResultOfMethodCallIgnored" )
@@ -105,11 +107,11 @@ public class JUnit4StackTraceWriter
         try
         {
             Throwable e = junitFailure.getException();
-            return SmartStackTraceParser.stackTraceWithFocusOnClassAsString( e, testClass );
+            return stackTraceWithFocusOnClassAsString( e, testClass );
         }
         catch ( Throwable t )
         {
-            return SmartStackTraceParser.stackTraceWithFocusOnClassAsString( t, testClass );
+            return stackTraceWithFocusOnClassAsString( t, testClass );
         }
     }
 
