@@ -19,7 +19,7 @@ package org.apache.maven.surefire.junitcore.pc;
  * under the License.
  */
 
-import org.apache.maven.surefire.report.ConsoleLogger;
+import org.apache.maven.surefire.report.ConsoleStream;
 import org.junit.runner.Description;
 import org.junit.runners.model.RunnerScheduler;
 
@@ -56,7 +56,7 @@ public class Scheduler
 
     private final Description description;
 
-    private final ConsoleLogger logger;
+    private final ConsoleStream logger;
 
     private volatile boolean shutdown = false;
 
@@ -72,7 +72,7 @@ public class Scheduler
      * You can use it with one infinite thread pool shared in strategies across all
      * suites, class runners, etc.
      */
-    public Scheduler( ConsoleLogger logger, Description description, SchedulingStrategy strategy )
+    public Scheduler( ConsoleStream logger, Description description, SchedulingStrategy strategy )
     {
         this( logger, description, strategy, -1 );
     }
@@ -81,8 +81,8 @@ public class Scheduler
      * Should be used if schedulers in parallel children and parent use one instance of bounded thread pool.
      * <p/>
      * Set this scheduler in a e.g. one suite of classes, then every individual class runner should reference
-     * {@link Scheduler(ConsoleLogger, org.junit.runner.Description, Scheduler, SchedulingStrategy)}
-     * or {@link Scheduler(ConsoleLogger, org.junit.runner.Description, Scheduler, SchedulingStrategy, int)}.
+     * {@link Scheduler(ConsoleStream, org.junit.runner.Description, Scheduler, SchedulingStrategy)}
+     * or {@link Scheduler(ConsoleStream, org.junit.runner.Description, Scheduler, SchedulingStrategy, int)}.
      *
      * @param logger current logger implementation
      * @param description description of current runner
@@ -90,7 +90,7 @@ public class Scheduler
      * @param concurrency determines maximum concurrent children scheduled a time via {@link #schedule(Runnable)}
      * @throws NullPointerException if null <tt>strategy</tt>
      */
-    public Scheduler( ConsoleLogger logger, Description description, SchedulingStrategy strategy, int concurrency )
+    public Scheduler( ConsoleStream logger, Description description, SchedulingStrategy strategy, int concurrency )
     {
         this( logger, description, strategy, BalancerFactory.createBalancer( concurrency ) );
     }
@@ -99,7 +99,7 @@ public class Scheduler
      * New instances should be used by schedulers with limited concurrency by <tt>balancer</tt>
      * against other groups of schedulers. The schedulers share one pool.
      * <p/>
-     * Unlike in {@link Scheduler(ConsoleLogger, org.junit.runner.Description, SchedulingStrategy, int)} which was
+     * Unlike in {@link Scheduler(ConsoleStream, org.junit.runner.Description, SchedulingStrategy, int)} which was
      * limiting the <tt>concurrency</tt> of children of a runner where this scheduler was set, <em>this</em>
      * <tt>balancer</tt> is limiting the concurrency of all children in runners having schedulers created by this
      * constructor.
@@ -110,7 +110,7 @@ public class Scheduler
      * @param balancer    determines maximum concurrent children scheduled a time via {@link #schedule(Runnable)}
      * @throws NullPointerException if null <tt>strategy</tt> or <tt>balancer</tt>
      */
-    public Scheduler( ConsoleLogger logger, Description description, SchedulingStrategy strategy, Balancer balancer )
+    public Scheduler( ConsoleStream logger, Description description, SchedulingStrategy strategy, Balancer balancer )
     {
         strategy.setDefaultShutdownHandler( newShutdownHandler() );
         this.logger = logger;
@@ -131,7 +131,7 @@ public class Scheduler
      * @param balancer        determines maximum concurrent children scheduled a time via {@link #schedule(Runnable)}
      * @throws NullPointerException if null <tt>masterScheduler</tt>, <tt>strategy</tt> or <tt>balancer</tt>
      */
-    public Scheduler( ConsoleLogger logger, Description description, Scheduler masterScheduler,
+    public Scheduler( ConsoleStream logger, Description description, Scheduler masterScheduler,
                       SchedulingStrategy strategy, Balancer balancer )
     {
         this( logger, description, strategy, balancer );
@@ -141,12 +141,12 @@ public class Scheduler
 
     /**
      * @param masterScheduler a reference to
-     * {@link Scheduler(ConsoleLogger, org.junit.runner.Description, SchedulingStrategy, int)}
-     *                        or {@link Scheduler(ConsoleLogger, org.junit.runner.Description, SchedulingStrategy)}
-     * @see Scheduler(ConsoleLogger, org.junit.runner.Description, SchedulingStrategy)
-     * @see Scheduler(ConsoleLogger, org.junit.runner.Description, SchedulingStrategy, int)
+     * {@link Scheduler(ConsoleStream, org.junit.runner.Description, SchedulingStrategy, int)}
+     *                        or {@link Scheduler(ConsoleStream, org.junit.runner.Description, SchedulingStrategy)}
+     * @see Scheduler(ConsoleStream, org.junit.runner.Description, SchedulingStrategy)
+     * @see Scheduler(ConsoleStream, org.junit.runner.Description, SchedulingStrategy, int)
      */
-    public Scheduler( ConsoleLogger logger, Description description, Scheduler masterScheduler,
+    public Scheduler( ConsoleStream logger, Description description, Scheduler masterScheduler,
                       SchedulingStrategy strategy, int concurrency )
     {
         this( logger, description, strategy, concurrency );
@@ -160,7 +160,7 @@ public class Scheduler
      * <p/>
      * Cached thread pool is infinite and can be always shared.
      */
-    public Scheduler( ConsoleLogger logger, Description description, Scheduler masterScheduler,
+    public Scheduler( ConsoleStream logger, Description description, Scheduler masterScheduler,
                       SchedulingStrategy strategy )
     {
         this( logger, description, masterScheduler, strategy, 0 );
@@ -215,12 +215,12 @@ public class Scheduler
         {
             stream.close();
         }
-        logger.info( out.toString() );
+        logger.println( out.toString() );
     }
 
     protected void logQuietly( String msg )
     {
-        logger.info( msg );
+        logger.println( msg );
     }
 
     /**
